MethodChannelDevicePermission class
- Inheritance
-
- Object
- PlatformInterface
- DevicePermissionPlatform
- MethodChannelDevicePermission
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPermissionStatus(
Permission permission) → Future< PermissionStatus> -
override
-
checkServiceStatus(
Permission permission) → Future< ServiceStatus> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAppSettings(
) → Future< bool> -
override
-
requestPermissions(
List< Permission> permissions) → Future<Map< Permission, PermissionStatus> > -
override
-
shouldShowRequestPermissionRationale(
Permission permission) → Future< bool> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited