DevicePermissionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DevicePermissionPlatform
Implementers

Constructors

DevicePermissionPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermissionStatus(Permission permission) Future<PermissionStatus>
checkServiceStatus(Permission permission) Future<ServiceStatus>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSettings() Future<bool>
requestPermissions(List<Permission> permissions) Future<Map<Permission, PermissionStatus>>
shouldShowRequestPermissionRationale(Permission permission) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DevicePermissionPlatform
getter/setter pair